@@ -1,5 +1,4 @@
-var _curry2 = require('./internal/_curry2');
-
+var _curry2 = /*#__PURE__*/require('./internal/_curry2');
 
 /**
  * Retrieve the value at a given path.
@@ -8,16 +7,20 @@ var _curry2 = require('./internal/_curry2');
  * @memberOf R
  * @since v0.2.0
  * @category Object
- * @sig [String] -> {k: v} -> v | Undefined
+ * @typedefn Idx = String | Int
+ * @sig [Idx] -> {a} -> a | Undefined
  * @param {Array} path The path to use.
  * @param {Object} obj The object to retrieve the nested property from.
  * @return {*} The data at `path`.
+ * @see R.prop
  * @example
  *
  *      R.path(['a', 'b'], {a: {b: 2}}); //=> 2
  *      R.path(['a', 'b'], {c: {b: 2}}); //=> undefined
  */
-module.exports = _curry2(function path(paths, obj) {
+
+
+var path = /*#__PURE__*/_curry2(function path(paths, obj) {
   var val = obj;
   var idx = 0;
   while (idx < paths.length) {
@@ -29,3 +32,4 @@ module.exports = _curry2(function path(paths, obj) {
   }
   return val;
 });
+module.exports = path;
\ No newline at end of file
